scxpand.data\_util.dataset
==========================

.. automodule:: scxpand.data_util.dataset

   
   .. rubric:: Functions

   .. autosummary::
   
      apply_post_normalization_augmentations
      apply_pre_normalization_augmentations
      cells_collate_fn
      compute_categorical_targets_from_batch_obs
      compute_soft_labels
      encode_categorical_features_batch
      encode_categorical_value
      get_dataloader_kwargs
   
   .. rubric:: Classes

   .. autosummary::
   
      CellsDataset
   